==> spirit_hub-0.0.1.0.tar.gz: spirit_hub-0.0.1.0/spec/factories/favorite_factory.rb <==
# frozen_string_literal: true

require 'faker'

FactoryBot.define do
  factory :doc_favorite, class: 'Favorite' do
    tagset do
      doc_data = {
        title: FactoryBot.generate(:generate_unique_doc_title),
        responsible: user_id
      }

      doc = FactoryBot.create(:doc, doc_data)
      FactoryBot.create(:tagset,
                        doc_ids: [doc.id],
                        title: doc.title,
                        last_current_user_name: %w[Jean Paul Jacques Sophie].sample,
                        end_date: Date.today + rand(1..30),
                        type: 'document',
                        current_state: 'À traiter')
    end

    trait :with_file do
      after(:create) do |favorite, _evaluator|
        tagset = favorite.tagset
        doc = tagset.docs.first

        File.open(Rails.root.join('packages/spirit_hub/spec/fixtures/files/pdf_sample.pdf'), 'rb') do |f|
          doc.type = 'file'
          doc.store(f)
          doc.save
        end

        DocPreviewWorker.new.perform(doc.id.to_s)
        tagset.update_doc_fields
        tagset.save
      end
    end

    trait :with_current_user do
      after(:create) do |favorite, _evaluator|
        tagset = favorite.tagset

        tagset.set(last_current_user_name: %w[Jean Paul Jacques Sophie].sample)
      end
    end

    trait :with_informed do
      after(:create) do |favorite, _evaluator|
        tagset = favorite.tagset

        users = FactoryBot.create_list(:user, rand(1..5))
        tagset.update(informed: users.map(&:id))
      end
    end

    trait :with_logs do
      after(:create) do |favorite|
        favorite.tagset.logs.create(action: 'Crée', user_id: favorite.user_id)
        20.times do
          favorite.tagset.logs.create(action: 'Modifier', user_id: favorite.user_id)
        end
      end
    end
  end

  factory :tagset_favorite, class: 'Favorite' do
    tagset do
      FactoryBot.create(:tagset,
                        type: 'directory',
                        title: FactoryBot.generate(:generate_unique_tagset_title), responsible: user_id,
                        percent: [0, 25, 50, 75, 100].sample)
    end
  end
end

==> spirit_hub-0.0.1.5.tar.gz: spirit_hub-0.0.1.5/spec/factories/favorite_factory.rb <==
# frozen_string_literal: true

require 'faker'

FactoryBot.define do
  factory :doc_favorite, class: 'Favorite' do
    tagset do
      doc = FactoryBot.create(:doc, responsible: user_id)
      FactoryBot.create(:tagset_doc,
                        doc_ids: [doc.id],
                        last_current_user_name: %w[Jean Paul Jacques Sophie].sample,
                        end_date: Date.today + rand(1..30),
                        current_state: 'À traiter')
    end

    trait :with_file do
      after(:create) do |favorite, _evaluator|
        tagset = favorite.tagset
        doc = tagset.docs.first

        File.open(Rails.root.join('packages/spirit_hub/spec/fixtures/files/pdf_sample.pdf'), 'rb') do |f|
          doc.type = 'file'
          doc.store(f)
          doc.save
        end

        DocPreviewWorker.new.perform(doc.id.to_s)
        tagset.save
      end
    end

    trait :with_current_user do
      after(:create) do |favorite, _evaluator|
        tagset = favorite.tagset

        tagset.set(last_current_user_name: %w[Jean Paul Jacques Sophie].sample)
      end
    end

    trait :with_informed do
      after(:create) do |favorite, _evaluator|
        tagset = favorite.tagset

        users = FactoryBot.create_list(:user, rand(1..5))
        tagset.update(informed: users.map(&:id))
      end
    end

    trait :with_logs do
      after(:create) do |favorite|
        favorite.tagset.logs.create(action: 'Crée', user_id: favorite.user_id)
        20.times do
          favorite.tagset.logs.create(action: 'Modifier', user_id: favorite.user_id)
        end
      end
    end
  end

  factory :tagset_favorite, class: 'Favorite' do
    tagset do
      FactoryBot.create(:tagset_directory,
                        :complete,
                        responsible: user_id,
                        percent: [0, 25, 50, 75, 100].sample)
    end
  end
end
